<?php

/**
 * Plugin activation
 */
include_once( trailingslashit( get_template_directory() ) . 'inc/plugin-activation.php' );

/**
 * Include Theme Costumization
 */
include_once( trailingslashit( get_template_directory() ) . 'inc/customizer.php' );

/**
 * Recommend the Kirki plugin
 */
include_once( trailingslashit( get_template_directory() ) . 'inc/lib/include-kirki.php' );

/**
 * Add Thumbnail regen size
 */
include_once( trailingslashit(  get_template_directory() ) . 'inc/lib/otf_regen_thumbs.php' );

/**
 * Leefa general setup
 */
add_action('after_setup_theme', 'leefa_setup');

if ( ! function_exists( 'leefa_setup' ) ) :

  function leefa_setup() {
    // Theme lang
    load_theme_textdomain( 'leefa', get_template_directory() . '/languages' );


    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    // This theme uses wp_nav_menu() in two locations.
    register_nav_menus ( 
      array(
      'primary' => __('Primary Menu', 'leefa'),
      )
    );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
     */
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size( 370, 297, true );
    /**
     * Add image size use otf_regen_thumbs.php
     */
    add_image_size( 'leefa_thumbnail', 400, 400, true ); //featured

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );
    /*
    * This theme styles the visual editor to resemble the theme style,
    * specifically font, colors, icons, and column width.
    */
    add_editor_style( 'assets/css/editor-style.css' );
    /**
     * Custom Header
     */
    $args = array(
        'default-image'      => '',
        'width'              => 1200,
        'height'             => 140,
        'header-text'        => false,
        'flex-width'         => true,
        'flex-height'        => true,
    );
    add_theme_support( 'custom-header', $args );

    add_theme_support( 'custom-background', array(
      'default-color' => 'ffffff',
    ) );

  }

endif;


/**
 * Leefa logo function
 * @return logo
 */
function leefa_logo() {
  $logoLink = get_theme_mod( 'header-logo', '' );
  if ( ! empty ($logoLink) ) {
    if ( ! ( is_404() ) && ( is_single() ) || ( is_page() ) ) : ?>
      <h2 class="logo-image">
        <a href="<?php echo esc_url( home_url( '/' ) );?>" class="navbar-brand" title="<?php echo esc_attr( get_bloginfo('name', 'display') );?>" rel="home">
          <img src="<?php echo esc_url( $logoLink );?>"  alt="<?php echo esc_attr(get_bloginfo('name', 'display'));?>" title="<?php echo get_bloginfo('name');?>">
        </a>
      </h2>
  <?php else : ?>
      <h1 class="logo-image">
        <a href="<?php echo esc_url( home_url( '/' ) );?>" class="navbar-brand" title="<?php echo esc_attr( get_bloginfo('name', 'display') );?>" rel="home">
          <img src="<?php echo esc_url( $logoLink );?>"  alt="<?php echo esc_attr(get_bloginfo('name', 'display'));?>" title="<?php echo get_bloginfo('name');?>">
        </a>
      </h1>
  <?php
    endif;
  } else {
    if ( ( is_single() ) || ( is_page() ) ) : ?>
      <div class="logo-none">
        <a href="<?php echo esc_url( home_url( '/' ) );?>" class="navbar-brand" title="<?php echo esc_attr( get_bloginfo('name', 'display') );?>" rel="home">
          <h2 class="logo-heading">
            <?php echo esc_attr(get_bloginfo('name', 'display'));?>
          </h2>
        </a>
        <span class="site-desc navbar-brand"><?php echo esc_attr(get_bloginfo('description'));?></span>
      </div>
  <?php else : ?>
      <div class="logo-none">
        <a href="<?php echo esc_url( home_url( '/' ) );?>" class="navbar-brand" title="<?php echo esc_attr( get_bloginfo('name', 'display') );?>" rel="home">
          <h1 class="logo-heading">
            <?php echo esc_attr(get_bloginfo('name', 'display'));?>
          </h1>
        </a>
        <span class="site-desc navbar-brand"><?php echo esc_attr(get_bloginfo('description'));?></span>
      </div>
  <?php
    endif;
  }
}
add_action('leefa_logo', 'leefa_logo');

/**
 * Leefa Bootstrap breadcrumb
 * 
 */
if ( ! function_exists('leefa_breadcrumb') ) : 
  function leefa_breadcrumb() {
    if(!is_home()) {
      echo '<ol class="breadcrumb">';
      echo '<li><a href="'.esc_url( home_url( '/' ) ).'"><i class="fa fa-home"></i></a></li>';
      if (is_single()) {
        echo '<li>';
        the_category(', ');
        echo '</li>';
        if (is_single()) {
          echo '<li>';
          the_title();
          echo '</li>';
        }
      } elseif (is_category()) {
        echo '<li>';
        single_cat_title();
        echo '</li>';
      } elseif (is_page() && (!is_front_page())) {
        echo '<li>';
        the_title();
        echo '</li>';
      } elseif (is_tag()) {
        echo '<li>Tag: ';
        single_tag_title();
        echo '</li>';
      } elseif (is_day()) {
        echo'<li>Archive for ';
        get_the_date('F jS, Y');
        echo'</li>';
      } elseif (is_month()) {
        echo'<li>Archive for ';
        get_the_date('F, Y');
        echo'</li>';
      } elseif (is_year()) {
        echo'<li>Archive for ';
        get_the_date('Y');
        echo'</li>';
      } elseif (is_author()) {
        echo'<li>Author Archives';
        echo'</li>';
      } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) {
        echo '<li>Blog Archives';
        echo'</li>';
      } elseif (is_search()) {
        echo'<li>Search Results';
        echo'</li>';
      }
      echo '</ol>';
    }
  }
endif;
add_action('get_leefa_breadcrumb', 'leefa_breadcrumb');

/**
 * Content width
 */
function leefa_content_width() {
  $GLOBALS['content_width'] = apply_filters( 'leefa_content_width', 900 );
}
add_action( 'after_setup_theme', 'leefa_content_width', 0 );

/**
 * Register Widget Area
 */
function leefa_widgets_init() {
    register_sidebar(array(
      'name' => __( 'Left Sidebar', 'leefa' ),
      'id' => 'leefa-sidebarleft',
      'description' => __('Add widgets here to appear in your sidebar', 'leefa'),
      'before_title' => '<div class="title"><h3 class="widget-title"><span>',
      'after_title' => '</h3></div>',
      'before_widget' => '<aside id="%1$s" class="widget %2$s">', 
      'after_widget' => '</aside>',
    ));

    register_sidebar(array(
      'name' => __( 'Right Sidebar', 'leefa'),
      'id' => 'leefa-sidebarright',
      'description' => __('Add widgets here to appear in your sidebar', 'leefa'),
      'before_title' => '<div class="title"><h3 class="widget-title"><span>',
      'after_title' => '</h3></div>',
      'before_widget' => '<aside id="%1$s" class="widget %2$s">', 
      'after_widget' => '</aside>',
    ));

}
add_action( 'widgets_init', 'leefa_widgets_init' );

/**
 * Include Bootstrap Navwalker
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/lib/wp_bootstrap_navwalker.php' );

if( !function_exists('leefa_primary_menu')) {
  function leefa_primary_menu() {
    wp_nav_menu( array(
            'menu'              => 'primary',
            'theme_location'    => 'primary',
            'depth'             => 3,
            'menu_class'        => 'nav navbar-nav',
            'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
            'walker'            => new wp_bootstrap_navwalker())
        );
  }
}
add_action( 'leefa_nav_menu', 'leefa_primary_menu');

/**
 * Enqueue scripts and styles.
 *
 * @since  Leefa 1.0
 */
function leefa_stylesheet() {
  // Google Font
  wp_enqueue_style( 'leefa-google-fonts', '//fonts.googleapis.com/css?family=Raleway:700|Open+Sans:400,700', false );
  // Bootstrap  Stylesheet.
  wp_enqueue_style('leefa-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), false, 'all');
  // Font Awesome
  wp_enqueue_style('leefa-font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), false, 'all');
  // Theme Stylesheet.
  wp_enqueue_style( 'leefa-style', get_stylesheet_uri() );
}
add_action('wp_enqueue_scripts', 'leefa_stylesheet');

function leefa_js() {
  // Bootstrap js
  wp_enqueue_script( 'leefa-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), false, true );
  // Dropdown js
  wp_enqueue_script( 'leefa-dropdown', get_template_directory_uri() . '/assets/js/dropdown.min.js', array(), false, true );
}
add_action('wp_enqueue_scripts', 'leefa_js');


/**
 * Pagination
 */
if (!function_exists('leefa_pagination')) {
  // Bootstrap pagination function
  function leefa_pagination($before = '', $after = '') {
    global $wpdb, $wp_query;
    $request = $wp_query->request;
    $posts_per_page = intval(get_query_var('posts_per_page'));
    $paged = intval(get_query_var('paged'));
    $numposts = $wp_query->found_posts;
    $max_page = $wp_query->max_num_pages;
    if ( $numposts <= $posts_per_page ) { return; }
    if(empty($paged) || $paged == 0) {
      $paged = 1;
    }
    $pages_to_show = 7;
    $pages_to_show_minus_1 = $pages_to_show-1;
    $half_page_start = floor($pages_to_show_minus_1/2);
    $half_page_end = ceil($pages_to_show_minus_1/2);
    $start_page = $paged - $half_page_start;
    if($start_page <= 0) {
      $start_page = 1;
    }
    $end_page = $paged + $half_page_end;
    if(($end_page - $start_page) != $pages_to_show_minus_1) {
      $end_page = $start_page + $pages_to_show_minus_1;
    }
    if($end_page > $max_page) {
      $start_page = $max_page - $pages_to_show_minus_1;
      $end_page = $max_page;
    }
    if($start_page <= 0) {
      $start_page = 1;
    }
 
    echo $before.'<nav><ul class="pagination">'."";
    if ($paged > 1) {
      $first_page_text = "&laquo;";
      echo '<li class="prev"><a href="'.get_pagenum_link().'" title="First">'.$first_page_text.'</a></li>';
    }
      
    $prevposts = get_previous_posts_link('&laquo; Previous');
    if($prevposts) { echo '<li>' . $prevposts  . '</li>'; }
    else { echo '<li class="disabled"><a href="#">&laquo; Previous</a></li>'; }
    
    for($i = $start_page; $i  <= $end_page; $i++) {
      if($i == $paged) {
        echo '<li class="active"><a href="#">'.$i.'</a></li>';
      } else {
        echo '<li><a href="'.get_pagenum_link($i).'">'.$i.'</a></li>';
      }
    }
    echo '<li class="">';
    next_posts_link('Next &raquo;');
    echo '</li>';
    if ($end_page < $max_page) {
      $last_page_text = "&raquo;";
      echo '<li class="next"><a href="'.get_pagenum_link($max_page).'" title="Last">'.$last_page_text.'</a></li>';
    }
    echo '</ul></nav>'.$after."";
  }
}
add_action('leefa_pagination', 'leefa_pagination');

/**
 * Excerpt Filter setting
 */
function leefa_excerpt_length($len) { 
  return 20; 
}
add_filter( 'excerpt_length', 'leefa_excerpt_length');
function leefa_excerpt_readmore($more) {
    global $post;
    return '...';
}
add_filter( 'excerpt_more', 'leefa_excerpt_readmore');


if ( ! function_exists( 'leefa_author' ) ) :
/**
 *  Leefa Author by
 */
  function leefa_author() {
    printf( '<span class="author-meta"><i class="fa fa-vcard-o fa-fw"></i> <a href="%1s" title="%2s" rel="author">%3s</a></span>',
      esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
          esc_attr( sprintf( __( 'View all posts by %s', 'leefa' ), get_the_author() ) ),
          get_the_author()
    );
  }
endif;

if (! function_exists( 'leefa_date_post' ) ) :
  /**
   * Date post
   */
  function leefa_date_post() {
    printf( '<span><i class="fa fa-hourglass-o fa-fw"></i><a class="dt-published" href="%1s" title="%2s" rel="bookmark"><time datetime="%3s">%4s</time></a></span>',
      esc_url( get_permalink() ),
      esc_attr( get_the_time() ),
      esc_attr( get_the_date('c') ),
      esc_attr( get_the_date('F j, Y') )
    );
  }
endif;

if ( ! function_exists( 'leefa_category' ) ) :
/**
 * Leefa Category Post
 */
  function leefa_category() {
    global $post;
      $category_list = get_the_category_list( ', ' );
      if ($category_list) {
        printf( '<span class="p-category"><i class="fa fa-folder-o fa-fw"></i> %1s</span>', $category_list );
      }
  }
endif;

if ( ! function_exists( 'leefa_comment_count' ) ) :
/**
 * Leefa Comment Count
 */
  function leefa_comment_count() {
  ?>
    <span class="comment-count-meta"><i class="fa fa-commenting-o fa-fw"></i> <?php comments_popup_link( __( 'Leave a comment', 'leefa' ), __( '1 Comment', 'leefa' ), __( '% Comments', 'leefa' ) ); ?>
</span>
  <?php
  }
endif;

/**
 * Leefa Time Ago
 */
if ( ! function_exists( 'leefa_time_ago' ) ) :
  function leefa_time_ago( $type = 'post' ) {
      printf( '<span class="time-ago"><i class="fa fa-hourglass-o fa-fw"></i> %s ' . __('ago', 'leefa') . '</span>', human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
  }
endif;

/**
 * Leefa Call All Meta
 * Call Meta Together.
 */
if ( ! function_exists( 'leefa_show_meta' ) ) :
  function leefa_show_meta() {
    echo '<div class="show-meta">';
    leefa_author();
    leefa_category();
    leefa_time_ago();
    leefa_comment_count();
    echo '</div>';
  }
endif;
add_action('do_leefa_show_meta', 'leefa_show_meta');

// Tags content filter
function leefa_after_content_tag($content){
  if (is_single()) { 
    $content .= '<div class="tag-row">';
    $content .= get_the_tag_list( sprintf( '<p class="p-category tag-list"><span class="title"> %s </span>', __( 'Tags:', 'leefa' ) ), ' ', '</p>' );
    $content .= '</div>';
  }
    return $content;
}
add_filter( 'the_content', 'leefa_after_content_tag');

function leefa_credit() {
  $url = '//rumblethemes.com';
  printf( '&copy; %1s <a href="%2s">%3s</a>. By <a href="%4s">Rumble Themes</a>.' ,
    esc_attr( date("Y") ),
    esc_url( home_url() ),
    esc_attr( get_bloginfo('name') ),
    esc_url( $url )
  );
}
add_action('do_credit', 'leefa_credit');

/**
 * Ads Function
 */
function leefa_header_ads() {
  $leefa_header_switch = get_theme_mod('leefa-ads-header-switch');
  $leefa_header_ads = get_theme_mod('leefa-ads-header');
  if ( true ==  $leefa_header_switch ) {
    echo $leefa_header_ads;
  }
}
add_action('leefa_header_ads','leefa_header_ads');

function leefa_before_content_ads( $content ) {
  $before = get_theme_mod('leefa-ads-before-content');
  $before_switch = get_theme_mod('leefa-ads-before-content-switch', true);
  if ( $before_switch == true && is_single() ) {
    $custom_content = '<div class="ads-before">'.$before.'</div>';
    $custom_content .= $content;
    return $custom_content;
  } else {
    return $content;
  }
}
add_filter( 'the_content', 'leefa_before_content_ads' );

function leefa_below_content_ads( $content ) {
  $below = get_theme_mod('leefa-ads-below-content');
  $below_switch = get_theme_mod('leefa-ads-below-content-switch', true);
  if ( true == $below_switch && is_single() ) {
    $content .= '<div class="ads-after">'.$below.'</div>';
  }
    return $content;
}
add_filter('the_content', 'leefa_below_content_ads');











