<?php

/**
 * Kirki Advanced Customizer
 * @package  leefa
 */
// Exit if Kirki is not installed
if ( ! class_exists( 'Kirki' ) ) {
	return;
}
/** Register Kirki config */
Kirki::add_config( 'leefa_settings', array(
	'capability'	=> 'edit_theme_options',
	'option_type'	=> 'theme_mod',
) );

load_theme_textdomain( 'leefa', get_template_directory() . '/languages' );

/**
 * Remove WP Default Sections
 *
 * @since 1.0
 */
function leefa_theme_customize_register( $wp_customize ) {
	$wp_customize->remove_section('colors');
}
add_action( 'customize_register', 'leefa_theme_customize_register' );


###################################################################################
# STYLING SETTINGS
###################################################################################


// COLOR SETTING
Kirki::add_section( 'color_settings', array(
	'title'			=> __( 'Color Settings', 'leefa' ),
	'description'	=> __( 'Color settings.', 'leefa' ),

) );

// -> BODY BACKGROUND
Kirki::add_section( 'background_image', array(
	'title'			=> __( 'Body Background', 'leefa' ),
	'description'	=> __( 'Body background settings.', 'leefa' ),

) );

// -> Body background color
Kirki::add_field( 'leefa_settings', array(
	'type'			=> 'color',
	'settings'		=> 'background-color',
	'label'			=> __('Background Color', 'leefa'),
	'description'	=> __('Choose background color scheme.', 'leefa'),
	'section'		=> 'color_settings',
	'default'		=> '#FFFFFF',
	'priority'		=> 10,
	'alpha'			=> true,
	'output'		=> array(
		array (
			'element'		=> 'body',
			'property'		=> 'background-color',
		),
	),
) );

// -> Add Color
Kirki::add_field( 'leefa_settings', array(
	'type'			=> 'color',
	'settings'		=> 'primary-color',
	'label'			=> __('Primary Color', 'leefa'),
	'description'	=> __('Choose primary color scheme.', 'leefa'),
	'section'		=> 'color_settings',
	'default'		=> '#E64A19',
	'priority'		=> 10,
	'alpha'			=> true,
	'output'		=> array(
		array (
			'element'		=> array(
				'.navigation .menu, .widget .tagcloud a, .tag-row .tag-list .title',
			),
			'property'		=> 'background-color',
		),
		array (
			'element'		=>  array (
				'.show-meta .author-meta a, .to-article:hover, .navigation .navbar-classic .navbar-logo a, .tag-row .tag-list a:hover',
			),
			'property'		=> 'color',
		),
		array (
			'element'		=> '.bypostauthor > .comment-body .comment-author .avatar',
			'property'		=> 'border-color',
		),
	),
) );
Kirki::add_field( 'leefa_settings', array(
	'type'			=> 'color',
	'settings'		=> 'secondary-color',
	'label'			=> __('Secondary Color', 'leefa'),
	'description'	=> __('Choose secondary color scheme.', 'leefa'),
	'section'		=> 'color_settings',
	'default'		=> '#607D8B',
	'priority'		=> 10,
	'alpha'			=> true,
	'output'		=> array(
		array (
			'element'		=> array (
				'.navigation .navbar-nav > li > a:hover, .navigation .navbar-nav > li > a:focus,
			    .navigation .navbar-nav > .active > a, .navigation .navbar-nav > .active > a:focus, .navigation .navbar-nav > .active > a:hover,
			    .navigation .navbar-nav > .open > a, .navigation .navbar-nav > .open > a:focus, .navigation .navbar-nav > .open > a:hover,
			    .dropdown-menu,
			    .dropdown-menu > .active > a:focus, .dropdown-menu > .active > a:hover,
			    .pagination .active a, .pagination .active a:focus, .pagination .active a:hover, .pagination .active span, .pagination .active span:focus, .pagination .active span:hover,
			    .form-submit input[type=submit]#comment-submit,
			    .dropdown-submenu.open > a, .dropdown-submenu.open > a:focus, 
			    .dropdown-submenu.open > a:hover',
			),
			'property'		=> 'background-color',
		),
		array (
			'element'		=> array (
				'.navigation .menu',
			),
			'property'		=> 'border-bottom-color',
		),
		array (
			'element'		=> array (
				'.pagination li a, .pagination li span,.to-article, .show-meta .author-meta a:hover',
			),
			'property'		=> 'color',
		),
		array (
			'element'		=> array (
				'.pagination .active a, .pagination .active a:focus, .pagination .active a:hover, .pagination .active span, .pagination .active span:focus, .pagination .active span:hover',
			),
			'property'		=> 'border-color',
		),
	),
) );
Kirki::add_field( 'leefa_settings', array(
    'type'        => 'multicolor',
    'settings'    => 'link-color',
    'label'       => __( 'Link Color', 'leefa' ),
    'section'     => 'color_settings',
    'priority'    => 10,
    'choices'     => array(
        'link'    => __( 'Color', 'leefa' ),
        'hover'   => __( 'Hover', 'leefa' ),
    ),
    'default'     => array(
        'link'    => '#212121',
        'hover'   => '#607D8B',
    ),
    'output'	  => array (
    	array(
    		'element'		=> 'a',
    		'property'		=> 'color',
    		'choice'		=> 'link',
    	),
    	array(
    		'element'		=> array(
    			'a:hover, a:focus, a:active',
    		),
    		'property'		=> 'color',
    		'choice'		=> 'hover',
    	),
    ),
) );

###################################################################################
# ADS SETTINGS
###################################################################################
// ADS SECTION
Kirki::add_section( 'ads_setting', array(
	'title'			=> __('Ads Settings', 'leefa'),
	'description'	=> __('You can insert your ads script here.', 'leefa'),
	'priority'      => 10,
) );
// Add Ads header
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'switch',
	'settings'    => 'leefa-ads-header-switch',
	'label'       => __( 'Enable ads on header?', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '1',
	'priority'    => 10,
	'choices'     => array(
		'on'  => esc_attr__( 'On', 'leefa' ),
		'off' => esc_attr__( 'Off', 'leefa' ),
	),
) );
// Header ads
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'textarea',
	'settings'    => 'leefa-ads-header',
	'label'       => __( 'Ads Header', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '<img src="' . get_template_directory_uri() . '/assets/img/72890.png">',
	'priority'    => 10,
	'active_callback'    => array(
		array(
			'setting'  => 'leefa-ads-header-switch',
			'operator' => '==',
			'value'    => 1,
		),
	),
) );

// Add Ads Below Title post
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'switch',
	'settings'    => 'leefa-ads-before-content-switch',
	'label'       => __( 'Enable ads below title post?', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '1',
	'priority'    => 10,
	'choices'     => array(
		'on'  => esc_attr__( 'On', 'leefa' ),
		'off' => esc_attr__( 'Off', 'leefa' ),
	),
) );
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'textarea',
	'settings'    => 'leefa-ads-before-content',
	'label'       => __( 'Ads below title post', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '<img src="' . get_template_directory_uri() . '/assets/img/300250.png">',
	'priority'    => 10,
	'active_callback'    => array(
		array(
			'setting'  => 'leefa-ads-before-content-switch',
			'operator' => '==',
			'value'    => 1,
		),
	),
) );
// Add Ads below content
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'switch',
	'settings'    => 'leefa-ads-below-content-switch',
	'label'       => __( 'Enable ads below content post?', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '1',
	'priority'    => 10,
	'choices'     => array(
		'on'  => esc_attr__( 'On', 'leefa' ),
		'off' => esc_attr__( 'Off', 'leefa' ),
	),
) );
Kirki::add_field( 'leefa_settings', array(
	'type'        => 'textarea',
	'settings'    => 'leefa-ads-below-content',
	'label'       => __( 'Ads below content', 'leefa' ),
	'section'     => 'ads_setting',
	'default'     => '<img src="' . get_template_directory_uri() . '/assets/img/300250.png">',
	'priority'    => 10,
	'active_callback'    => array(
		array(
			'setting'  => 'leefa-ads-below-content-switch',
			'operator' => '==',
			'value'    => 1,
		),
	),
) );

###################################################################################
# LOGO SETTINGS
###################################################################################
// Add Logo
Kirki::add_field( 'leefa_settings', array(
	'type'			=> 'image',
	'settings'		=> 'header-logo',
	'label'			=> __( 'Logo', 'leefa' ),
	'description'	=> __( 'Upload your logo. Max Height 100px', 'leefa' ),
	'section'		=> 'title_tagline',
	'default'		=> '',
	'priority'		=> 10,
) );

/**
 * Configuration for the Leefa Kirki Customizer.
 * The function's argument is an array of existing config values
 * The function returns the array with the addition of our own arguments
 * and then that result is used in the kirki/config filter
 *
 * @param $config the configuration array
 *
 * @return array
 */
function leefa_configuration( $config ) {

	return wp_parse_args(array(
		'logo_image'		=> get_template_directory_uri() . '/assets/img/panelbrand.png',
		'description'  		=> esc_attr__( 'Welcome to control panel.', 'leefa' ),
		'color_back'		=> '#232a4b',
		'color_accent'		=> '#0085ba',
		'width'				=> '20%',
	), $config );
}
add_filter( 'kirki/config', 'leefa_configuration' );